/* This file is part of smap.
   Copyright (C) 2006, 2007, 2010 Sergey Poznyakoff

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>. */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif
#include <stdio.h>
#include "smap/diag.h"

static void
flush_stderr(const char *pfx, void *data, char *buf)
{
	if (pfx)
		fprintf(stderr, "%s: %s: %s\n", smap_progname, pfx, buf);
	else
		fprintf(stderr, "%s: %s\n", smap_progname, buf);
}

static void
flush_stderr_err(void *data, char *buf)
{
	flush_stderr(NULL, data, buf);
}

static void
flush_stderr_dbg(void *data, char *buf)
{
	flush_stderr("DEBUG", data, buf);
}

static void
flush_stderr_trc(void *data, char *buf)
{
	flush_stderr("TRACE", data, buf);
}

void
smap_openlog_stderr(int trace)
{
	smap_ostream_destroy(&smap_error_str);
	smap_ostream_destroy(&smap_debug_str);
	smap_ostream_destroy(&smap_trace_str);

	smap_error_str = smap_ostream_create(flush_stderr_err, NULL);
	smap_debug_str = smap_ostream_create(flush_stderr_dbg, NULL);
	if (trace)
		smap_trace_str = smap_ostream_create(flush_stderr_trc,
						     NULL);
}
